@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -170,6 +170,14 @@ class UWC_Image {
     return null;
   }
 
+  function get_news() {
+    return null;
+  }
+
+  function get_rss() {
+    return null;
+  }
+
   function exists() {
     return $this->image_exists();
   }
